package com.platonoff.www;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.net.URL;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
  A picture gallery servlet filter.

  (c) 2001-2006 Dmitry I. Platonoff <dmitry@platonoff.com>
*/
public class PictureServletFilter implements Filter {

   /** image suffix */
  protected final static String IMAGE_SUFFIX = ".jpg";
   /** image suffix */
  protected final static String REFERER = "referer";

   /** config wrapper */
  protected PictureServletConfig config = null;
   /** hotlink image buffer */
  protected byte[] hotlinkImage = null;


   /** Initializes the filter */
  public void init( FilterConfig config ) throws ServletException {
    this.config = new PictureServletConfig( config.getServletContext()
      .getResourceAsStream( PictureServletConfig.CONFIG_PATH ) );

    String imagePath = this.config.getHotlinkImagePath();
    if ( imagePath != null ) try {
      File hotlinkImageFile =
        new File( config.getServletContext().getRealPath( imagePath ) );

      hotlinkImage = new byte[( int ) hotlinkImageFile.length()];

      FileInputStream fis = new FileInputStream( hotlinkImageFile );
      fis.read( hotlinkImage );
      fis.close();
    }
    catch ( IOException ioException ) {
      throw new ServletException( ioException );
    }
  }
         

   /** Cleans up. */
  public void destroy() {}
                     
                     
   /** Filters. */
  public void doFilter( ServletRequest request, ServletResponse response,
      FilterChain next ) throws ServletException, IOException {
    if ( request instanceof HttpServletRequest ) {
      HttpServletRequest req = ( HttpServletRequest ) request;
      String uri = req.getRequestURI();
      if ( uri.endsWith( IMAGE_SUFFIX ) ) {
        String referer = req.getHeader( REFERER );
        if ( referer != null ) {
          String refererHost = new URL( referer ).getHost();
          String localHost = req.getServerName();
          if ( refererHost != null &&
              localHost != null &&
              ! refererHost.equals( localHost ) &&
              config.checkForHotlinks( uri, refererHost ) ) {
            response.setContentType( config.getHotlinkImageContentType() );
            response.setContentLength( hotlinkImage.length );
            response.getOutputStream().write( hotlinkImage );
            return;
          }
        }
      }
    }
    next.doFilter( request, response );
  }
}
