<!--

  Picture set template for Resin

  Author: <A HREF="mailto:dmitry@platonoff.com">Dmitry I. Platonoff</A>
  $Revision: $
  $Log: $
-->
<?xml version="1.0" encoding="koi8-r"?>
<xsl:output
  method='html'
  disable-output-escaping='true'
  indent='false'
  omit-html-declaration='true'
  encoding='koi8-r'
/>


<xsl:template name='directory-list'>
  <xsl:if test='directory or @has-parent="true"'>
    <BR/>
    <TABLE WIDTH="90%" CELLPADDING=10 CELLSPACING=0 BORDER=0>
      <TR VALIGN=TOP>
        <TD NOWRAP>
          <UL>
            <xsl:if test='@has-parent="true"'>
              <LI><A HREF=".." CLASS="textEm">[parent folder]</A></LI>
            </xsl:if>
            <xsl:for-each select='directory'>
              <xsl:sort select='@name' order='descending'/>
              <LI>
                <A CLASS="textEm">
                  <xsl:attribute name='HREF'><{@name}>/</xsl:attribute>
                  <{@title}>
                </A>
              </LI>
            </xsl:for-each>
          </UL>
        </TD>
        <TD>
          <xsl:apply-templates select='text(.)|*[not(name(.)="directory" or name(.)="picture")]'/>
        </TD>
      </TR>
    </TABLE>
  </xsl:if>
</xsl:template>


<!--
  Picture set template
-->
<xsl:template match='picture-set'>
  <xsl:call-template name='directory-list'/>
  <xsl:variable name='columns'>
    <xsl:choose>
      <xsl:when test='@columns'><{@columns}></xsl:when>
      <xsl:otherwise>4</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:if test='picture'>
    <CENTER>
      <TABLE BORDER=0 CELLPADDING=5 CELLSPACING=0>
        <TR VALIGN=TOP>
        <xsl:for-each select='picture'>
          <TD ALIGN=CENTER>
            <A>
              <xsl:attribute name='HREF'>?i=<{@name}></xsl:attribute>
              <IMG BORDER=0 ALT="">
                <xsl:attribute name='SRC'><{../@thumbnail-location}>/<{@name}></xsl:attribute>
                <xsl:if test='thumbnail/@width'>
                  <xsl:attribute name='WIDTH'><{thumbnail/@width}></xsl:attribute>
                </xsl:if>
                <xsl:if test='thumbnail/@height'>
                  <xsl:attribute name='HEIGHT'><{thumbnail/@height}></xsl:attribute>
                </xsl:if>
              </IMG>
            </A>
            <xsl:if test='not(../@index-with-comments="true")'>
              <xsl:call-template name='date-parties-title-3'/>
            </xsl:if>
          </TD>
          <xsl:if test='../@index-with-comments="true"'>
            <TD>
              <B><xsl:call-template name='date-parties-title-2'/></B>
              <BR/>
              <xsl:apply-templates select='text(.)|*[not(name(.)="image" or name(.)="thumbnail")]'/>
            </TD>
          </xsl:if>
          <xsl:if test='(position() mod $columns) = 0'>&lt;/TR&gt;&lt;TR VALIGN=TOP&gt;</xsl:if>
        </xsl:for-each>
        </TR>
      </TABLE>
    </CENTER>
    <P/>&amp;nbsp;
  </xsl:if>
</xsl:template>


<!--
  Picture set template
-->
<xsl:template match='picture-set[@selected]'>
  <xsl:if test='picture'>
    <BR/>
    <TABLE BORDER=0 CELLPADDING=2 CELLSPACING=0 WIDTH="50%" ALIGN=CENTER>
      <TR><TD ALIGN=CENTER>
        <xsl:for-each select='picture'>
          <xsl:variable name='picture-title'>
            <xsl:call-template name='date-parties-title-1'/>
          </xsl:variable>
          <A>
            <xsl:attribute name='HREF'>?i=<{@name}></xsl:attribute>
            <xsl:attribute name='TITLE'><{$picture-title}></xsl:attribute>
            <xsl:choose>
              <xsl:when test='@name=../@selected'><B><{position()}></B></xsl:when>
              <xsl:otherwise><{position()}></xsl:otherwise>
            </xsl:choose>
          </A>
          <xsl:choose>
            <xsl:when test='(position() mod "30") = "0"'><BR/></xsl:when>
            <xsl:otherwise><xsl:text> </xsl:text></xsl:otherwise>
          </xsl:choose>
        </xsl:for-each>
        <A HREF="." TITLE="Directory Index">[index]</A>
      </TD></TR>
      <xsl:for-each select='picture[@name=../@selected]'>
        <TR><TD ALIGN=CENTER>
          <A>
            <xsl:attribute name='HREF'>
              <xsl:choose>
                <xsl:when test='following-sibling::picture'>
                  <xsl:text>?i=</xsl:text>
                  <{following-sibling::picture/@name}>
                </xsl:when>
                <xsl:otherwise>.</xsl:otherwise>
              </xsl:choose>
            </xsl:attribute>
            <IMG BORDER=0 ALT="Click to see the next picture">
              <xsl:attribute name='SRC'><{@name}></xsl:attribute>
              <xsl:if test='image/@width'>
                <xsl:attribute name='WIDTH'><{image/@width}></xsl:attribute>
              </xsl:if>
              <xsl:if test='image/@height'>
                <xsl:attribute name='HEIGHT'><{image/@height}></xsl:attribute>
              </xsl:if>
            </IMG>
          </A>
        </TD></TR>
        <TR><TD><B><xsl:call-template name='date-parties-title-1'/></B></TD></TR>
        <TR><TD>
          <xsl:apply-templates select='text(.)|*[not(name(.)="image" or name(.)="thumbnail")]'/>
        </TD></TR>
      </xsl:for-each>
    </TABLE>
  </xsl:if>
  <xsl:call-template name='directory-list'/>
</xsl:template>

<!--
  Date, parties and title display template
-->
<xsl:template name='date-parties-title-3'>
  <xsl:if test='@date'><BR/><B><{@date}></B></xsl:if>
  <xsl:if test='@parties'><BR/><{@parties}></xsl:if>
  <xsl:if test='@title'><BR/><{@title}></xsl:if>
</xsl:template>

<!--
  Date, parties and title display template
-->
<xsl:template name='date-parties-title-2'>
  <xsl:if test='@date'><{@date}>
    <xsl:if test='(@parties)or(@title)'><BR/></xsl:if>
  </xsl:if>
  <xsl:if test='@parties'><{@parties}>
    <xsl:if test='@title'>: </xsl:if>
  </xsl:if>
  <xsl:if test='@title'><{@title}></xsl:if>
</xsl:template>

<!--
  Date, parties and title display template
-->
<xsl:template name='date-parties-title-1'>
  <xsl:if test='@date'><{@date}>
    <xsl:if test='(@parties)or(@title)'>: </xsl:if>
  </xsl:if>
  <xsl:if test='@parties'><{@parties}>
    <xsl:if test='@title'>: </xsl:if>
  </xsl:if>
  <xsl:if test='@title'><{@title}></xsl:if>
</xsl:template>

<!--
  Picture item template
-->
<xsl:template match='picture-item'>
  <TABLE BORDER=0 CELLPADDING=1 CELLSPACING=0 WIDTH="100%">
    <TR><TD CLASS="borderBg">
      <TABLE BORDER=0 CELLPADDING=5 CELLSPACING=0 WIDTH="100%">
        <TR VALIGN=TOP>
          <xsl:if test='image'>
            <TD CLASS="bg" WIDTH="1%">
              <A>
                <xsl:attribute name='HREF'><{@url}></xsl:attribute>
                <IMG BORDER=0 ALT="">
                  <xsl:attribute name='SRC'><{image/@src}></xsl:attribute>
                  <xsl:if test='image/@width'>
                    <xsl:attribute name='WIDTH'><{image/@width}></xsl:attribute>
                  </xsl:if>
                  <xsl:if test='image/@height'>
                    <xsl:attribute name='HEIGHT'><{image/@height}></xsl:attribute>
                  </xsl:if>
                </IMG>
              </A>
            </TD>
          </xsl:if>
          <TD CLASS="bg">
            <A CLASS="textEm">
              <xsl:attribute name='HREF'><{@url}></xsl:attribute>
              <xsl:call-template name='date-parties-title-1'/>
            </A>
            <BR/>
            <xsl:apply-templates select='text(.)|*[not(name(.)="image")]'/>
          </TD>
        </TR>
      </TABLE>
    </TD></TR>
  </TABLE>
</xsl:template>


<!--
  News item template
-->
<xsl:template match='picture-gallery-news'>
  <TABLE BORDER=0 CELLPADDING=4 CELLSPACING=0 WIDTH="100%">
    <xsl:for-each select='news-item'>
      <TR>
        <TD CLASS="tableHeader">
          <A CLASS="textEm">
            <xsl:attribute name='HREF'><{@url}></xsl:attribute>
            <xsl:call-template name='date-parties-title-1'/>
          </A>
        </TD>
      </TR>
      <TR>
        <TD CLASS="bg" STYLE="padding-left: 20px">
          <xsl:apply-templates/>
        </TD>
      </TR>
    </xsl:for-each>
  </TABLE>
</xsl:template>
